<?php
/**
 * Helper functions for the admin - plugin links and help tabs.
 *
 * @package    Xtreme One Toolbar
 * @subpackage Admin
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2012-2014, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/xtreme-one-toolbar/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.2.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Setting internal plugin helper values.
 *
 * @since  1.2.0
 *
 * @uses   ddw_xotb_is_german() To detect German locale based environment.
 *
 * @return array Array of external info link url strings.
 */
function ddw_xotb_info_values() {

	$xotb_info = array(

		'url_translate'     => 'http://translate.wpautobahn.com/projects/wordpress-plugins-deckerweb/xtreme-one-toolbar',
		'url_wporg_faq'     => 'http://wordpress.org/plugins/xtreme-one-toolbar/faq/',
		'url_wporg_forum'   => 'http://wordpress.org/support/plugin/xtreme-one-toolbar',
		'url_wporg_profile' => 'http://profiles.wordpress.org/daveshine/',
		'url_snippets'      => 'https://gist.github.com/deckerweb/2519992',
		'url_suggestions'   => 'https://deckerweb.de/twitter',
		'license'           => 'GPL-2.0+',
		'first_release'     => absint( '2012' ),
		'url_donate'        => ddw_xotb_is_german() ? 'http://genesisthemes.de/spenden/' : 'http://genesisthemes.de/en/donate/',
		'url_plugin'        => ddw_xotb_is_german() ? 'http://genesisthemes.de/plugins/xtreme-one-toolbar/' : 'http://genesisthemes.de/en/wp-plugins/xtreme-one-toolbar/'

	);  // end of array

	return $xotb_info;

}  // end of function ddw_xotb_info_values


add_filter( 'plugin_row_meta', 'ddw_xotb_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page.
 *
 * @since  1.0.0
 *
 * @uses   ddw_xotb_info_values()
 *
 * @param  $xotb_links
 * @param  $xotb_file
 *
 * @return string Strings of plugin links.
 */
function ddw_xotb_plugin_links( $xotb_links, $xotb_file ) {

	/** Capability check */
	if ( ! current_user_can( 'install_plugins' ) ) {

		return $xotb_links;

	}  // end if

	/** List additional links only for this plugin */
	if ( $xotb_file == XOTB_PLUGIN_BASEDIR . 'xtreme-one-toolbar.php' ) {

		$xotb_info = (array) ddw_xotb_info_values();

		$xotb_links[] = '<a href="' . esc_url( $xotb_info[ 'url_wporg_faq' ] ) . '" target="_new" title="' . __( 'FAQ', 'xtreme-one-toolbar' ) . '">' . __( 'FAQ', 'xtreme-one-toolbar' ) . '</a>';

		$xotb_links[] = '<a href="' . esc_url( $xotb_info[ 'url_wporg_forum' ] ) . '" target="_new" title="' . __( 'Support', 'xtreme-one-toolbar' ) . '">' . __( 'Support', 'xtreme-one-toolbar' ) . '</a>';

		$xotb_links[] = '<a href="' . esc_url( $xotb_info[ 'url_snippets' ] ) . '" target="_new" title="' . __( 'Code Snippets for Customization', 'xtreme-one-toolbar' ) . '">' . __( 'Code Snippets', 'xtreme-one-toolbar' ) . '</a>';

		$xotb_links[] = '<a href="' . esc_url( $xotb_info[ 'url_translate' ] ) . '" target="_new" title="' . __( 'Translations', 'xtreme-one-toolbar' ) . '">' . __( 'Translations', 'xtreme-one-toolbar' ) . '</a>';

		$xotb_links[] = '<a href="' . esc_url( $xotb_info[ 'url_donate' ] ) . '" target="_new" title="' . __( 'Donate', 'xtreme-one-toolbar' ) . '">' . __( 'Donate', 'xtreme-one-toolbar' ) . '</a>';

	}  // end if

	/** Output the links */
	return apply_filters( 'xotb_filter_plugin_links', $xotb_links );

}  // end of function ddw_xotb_plugin_links


add_action( 'admin_init', 'ddw_xotb_xtremeone_load_help', 100 );
/**
 * Load plugin help tab on Xtreme One admin page.
 *
 * @since  1.2.0
 *
 * @global mixed $xtreme_backend, $xtremelayouts, $xtremebackup, $xtreme_widgets_admin
 */
function ddw_xotb_xtremeone_load_help() {

	global $xtreme_backend, $xtremelayouts, $xtremebackup, $xtreme_widgets_admin;

	if ( $xtremelayouts ) {

		add_action( 'load-' . $xtremelayouts->pagehook, 'ddw_xotb_xtremeone_help', 15 );

	}  // end-if

	if ( $xtremebackup ) {

		add_action( 'load-' . $xtremebackup->pagehook, 'ddw_xotb_xtremeone_help', 15 );

	}  // end-if

	if ( $xtreme_widgets_admin ) {

		add_action( 'load-' . $xtreme_widgets_admin->pagehook, 'ddw_xotb_xtremeone_help', 15 );

	}  // end-if

}  // end of function ddw_xotb_edd_load_help


add_action( 'load-toplevel_page_xtreme_backend', 'ddw_xotb_xtremeone_help', 16 );
/**
 * Setup plugin help tab.
 *
 * @since  1.2.0
 *
 * @uses   get_current_screen()
 * @uses   WP_Screen::add_help_tab
 * @uses   WP_Screen::set_help_sidebar
 * @uses   ddw_xotb_help_sidebar_content_extra()
 * @uses   ddw_xotb_help_sidebar_content()
 *
 * @global mixed $xotb_xtremeone_screen
 */
function ddw_xotb_xtremeone_help() {

	global $xotb_xtremeone_screen;

	$xotb_xtremeone_screen = get_current_screen();

	/** Display help tabs only for WordPress 3.3 or higher */
	if( ! class_exists( 'WP_Screen' )
		|| ! $xotb_xtremeone_screen
		|| ( defined( 'XOTB_DISPLAY' ) && ! XOTB_DISPLAY )
	) {

		return;

	}  // end if

	/** Add the help tab */
	$xotb_xtremeone_screen->add_help_tab( array(
		'id'       => 'xtremeone-toolbar-help',
		'title'    => __( 'Xtreme One Toolbar', 'xtreme-one-toolbar' ),
		'callback' => apply_filters( 'xotb_filter_help_tab_content', 'ddw_xotb_help_tab_content' ),
	) );

	/** Add help sidebar */
	$xotb_xtremeone_screen->set_help_sidebar( ddw_xotb_help_sidebar_content_extra() . ddw_xotb_help_sidebar_content() );

}  // end of function ddw_xotb_edd_help


/**
 * Create and display plugin help tab content.
 *
 * @since 1.2.0
 *
 * @uses  ddw_xotb_info_values()
 * @uses  ddw_xotb_plugin_get_data()
 */
function ddw_xotb_help_tab_content() {

	$xotb_info = (array) ddw_xotb_info_values();

	echo '<h3>' . __( 'Plugin', 'xtreme-one-toolbar' ) . ': ' . __( 'Xtreme One Toolbar', 'xtreme-one-toolbar' ) . '</h3>' .		
		'<ul>' . 
			'<li><a href="' . esc_url( $xotb_info[ 'url_suggestions' ] ) . '" target="_new" title="' . __( 'Suggest new resource items, child themes or plugins for support', 'xtreme-one-toolbar' ) . '">' . __( 'Suggest new resource items, child themes or plugins for support', 'xtreme-one-toolbar' ) . '</a></li>' .
			'<li><a href="' . esc_url( $xotb_info[ 'url_snippets' ] ) . '" target="_new" title="' . __( 'Code snippets for customizing &amp; branding', 'xtreme-one-toolbar' ) . '">' . __( 'Code snippets for customizing &amp; branding', 'xtreme-one-toolbar' ) . '</a></li>';

		/** Optional: recommended plugins */
		if ( ! defined( 'WPGF_PLUGIN_BASEDIR' )
			|| ! defined( 'EDDSW_PLUGIN_BASEDIR' )
			|| ! defined( 'WPSPN_PLUGIN_BASEDIR' )
		) {

			echo '<li><em>' . sprintf( __( 'Other, recommended plugins by %s', 'xtreme-one-toolbar' ), esc_attr__( ddw_xotb_plugin_get_data( 'Author' ) ) ) . '</em>:';

			if ( ! defined( 'WPGF_PLUGIN_BASEDIR' ) ) {

				echo '<br />&raquo; <a href="https://github.com/deckerweb/wp-german-formal" target="_new" title="WP German Formal">WP German Formal</a> &mdash; ' . __( 'language pack plugin to make WordPress speak formal German language, especially in the admin area', 'xtreme-one-toolbar' );

			}  // end-if

			if ( ! defined( 'EDDSW_PLUGIN_BASEDIR' ) ) {

				echo '<br />&raquo; <a href="http://wordpress.org/extend/plugins/edd-search-widget/" target="_new" title="Easy Digital Downloads Search Widget">Easy Digital Downloads Search Widget</a> &mdash; ' . __( 'search functionality for the Download post type, independent from regular WordPress search', 'xtreme-one-toolbar' );

			}  // end-if

			if ( ! defined( 'WPSPN_PLUGIN_BASEDIR' ) ) {

				echo '<br />&raquo; <a href="http://wordpress.org/extend/plugins/wp-single-post-navigation/" target="_new" title="WP Single Post Navigation">WP Single Post Navigation</a> &mdash; ' . __( 'book-like browsing with single posts', 'xtreme-one-toolbar' );

			}  // end-if

			echo '</li>';

		}  // end-if

	/** Set first release year */
	$release_first_year = ( '' != $xotb_info[ 'first_release' ] && date( 'Y' ) != $xotb_info[ 'first_release' ] ) ? $xotb_info[ 'first_release' ] . '&#x02013;' : '';

	echo '</ul>' .
		'<p><strong>' . __( 'Important plugin links:', 'xtreme-one-toolbar' ) . '</strong>' . 
		'<br /><a href="' . esc_url( $xotb_info[ 'url_plugin' ] ) . '" target="_new" title="' . __( 'Plugin Homepage', 'xtreme-one-toolbar' ) . '">' . __( 'Plugin Homepage', 'xtreme-one-toolbar' ) . '</a> | <a href="' . esc_url( $xotb_info[ 'url_wporg_faq' ] ) . '" target="_new" title="' . __( 'FAQ', 'xtreme-one-toolbar' ) . '">' . __( 'FAQ', 'xtreme-one-toolbar' ) . '</a> | <a href="' . esc_url( $xotb_info[ 'url_wporg_forum' ] ) . '" target="_new" title="' . __( 'Support', 'xtreme-one-toolbar' ) . '">' . __( 'Support', 'xtreme-one-toolbar' ) . '</a> | <a href="' . esc_url( $xotb_info[ 'url_snippets' ] ) . '" target="_new" title="' . __( 'Code Snippets for Customization', 'xtreme-one-toolbar' ) . '">' . __( 'Code Snippets', 'xtreme-one-toolbar' ) . '</a> | <a href="' . esc_url( $xotb_info[ 'url_translate' ] ) . '" target="_new" title="' . __( 'Translations', 'xtreme-one-toolbar' ) . '">' . __( 'Translations', 'xtreme-one-toolbar' ) . '</a> | <a href="' . esc_url( $xotb_info[ 'url_donate' ] ) . '" target="_new" title="' . __( 'Donate', 'xtreme-one-toolbar' ) . '"><strong>' . __( 'Donate', 'xtreme-one-toolbar' ) . '</strong></a></p>';

	echo '<p><a href="http://www.opensource.org/licenses/gpl-license.php" target="_new" title="' . esc_attr( $xotb_info[ 'license' ] ). '">' . esc_attr( $xotb_info[ 'license' ] ). '</a> &#x000A9; ' . $release_first_year . date( 'Y' ) . ' <a href="' . esc_url( ddw_xotb_plugin_get_data( 'AuthorURI' ) ) . '" target="_new" title="' . esc_attr__( ddw_xotb_plugin_get_data( 'Author' ) ) . '">' . esc_attr__( ddw_xotb_plugin_get_data( 'Author' ) ) . '</a></p>';

}  // end of function ddw_xotb_help_tab_content


/**
 * Helper function for returning the Help Sidebar content.
 *
 * @since  1.2.0
 *
 * @uses   ddw_xotb_info_values()
 * @uses   ddw_xotb_plugin_get_data()
 *
 * @return string HTML content for help sidebar.
 */
function ddw_xotb_help_sidebar_content() {

	$xotb_info = (array) ddw_xotb_info_values();

	$xotb_help_sidebar_content = '<p><strong>' . __( 'More about the plugin author', 'xtreme-one-toolbar' ) . '</strong></p>' .
			'<p>' . __( 'Social:', 'xtreme-one-toolbar' ) . '<br /><a href="http://twitter.com/deckerweb" target="_blank" title="@ Twitter">Twitter</a> | <a href="http://www.facebook.com/deckerweb.service" target="_blank" title="@ Facebook">Facebook</a> | <a href="http://deckerweb.de/gplus" target="_blank" title="@ Google+">Google+</a> | <a href="' . esc_url( ddw_xotb_plugin_get_data( 'AuthorURI' ) ) . '" target="_blank" title="@ deckerweb.de">deckerweb</a></p>' .
			'<p><a href="' . esc_url( $xotb_info[ 'url_wporg_profile' ] ) . '" target="_blank" title="@ WordPress.org">@ WordPress.org</a></p>';

	return apply_filters( 'xotb_filter_help_sidebar_content', $xotb_help_sidebar_content );

}  // end of function ddw_xotb_help_sidebar_content


/**
 * Helper function for returning the Help Sidebar content - extra for plugin setting page.
 *
 * @since  1.2.0
 *
 * @uses   ddw_xotb_info_values()
 *
 * @return string Extra HTML content for help sidebar.
 */
function ddw_xotb_help_sidebar_content_extra() {

	$xotb_info = (array) ddw_xotb_info_values();

	$xotb_help_sidebar_content_extra = '<p><strong>' . __( 'Actions', 'xtreme-one-toolbar' ) . '</strong></p>' .
		'<p>&rarr; <a href="' . esc_url( $xotb_info[ 'url_wporg_forum' ] ) . '" target="_new">' . __( 'Support Forum', 'xtreme-one-toolbar' ) . '</a></p>' .
		'<p style="margin-top: -5px;">&rarr; <a href="' . esc_url( $xotb_info[ 'url_donate' ] ) . '" target="_new">' . __( 'Donate', 'xtreme-one-toolbar' ) . '</a></p><br />';

	return apply_filters( 'xotb_filter_help_sidebar_content_extra', $xotb_help_sidebar_content_extra );

}  // end of function ddw_xotb_help_sidebar_content_extra