<?php
/**
 * Helper functions for custom branding & capabilities
 *
 * @package    Xtreme One Toolbar
 * @subpackage Branding
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2012-2014, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/xtreme-one-toolbar/
 * @link       http://twitter.com/deckerweb
 *
 * @since      1.1.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.2.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Helper functions for returning a few popular roles/capabilities.
 *
 * @since  1.1.0
 *
 * @return string String of role/ capability.
 */
	/**
	 * Helper function for returning 'administrator' role/capability.
	 *
	 * @since  1.1.0
	 *
	 * @return string String of 'administrator' role.
	 */
	function __xotb_admin_only() {

		return 'administrator';
	}

	/**
	 * Helper function for returning 'editor' role/capability.
	 *
	 * @since  1.1.0
	 *
	 * @return string String of 'editor' role.
	 */
	function __xotb_role_editor() {

		return 'editor';
	}

	/**
	 * Helper function for returning 'edit_theme_options' capability.
	 *
	 * @since  1.1.0
	 *
	 * @return string String of 'edit_theme_options' capability
	 */
	function __xotb_cap_edit_theme_options() {

		return 'edit_theme_options';
	}

	/**
	 * Helper function for returning 'install_plugins' capability.
	 *
	 * @since  1.1.0
	 *
	 * @return string String of 'install_plugins' capability.
	 */
	function __xotb_cap_install_plugins() {

		return 'install_plugins';
	}

/** End of role/capability helper functions */



/**
 * Helper functions for returning colored icons.
 *
 * @since  1.1.0
 *
 * @return string Path/ string of colored icon image.
 */
	/**
	 * Helper function for returning the blue icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of blue icon.
	 */
	function __xotb_blue_icon() {

		return plugins_url( 'images/icon-xtreme-blue.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the gray icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of gray icon.
	 */
	function __xotb_gray_icon() {

		return plugins_url( 'images/icon-xtreme-gray.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the green icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of green icon.
	 */
	function __xotb_green_icon() {

		return plugins_url( 'images/icon-xtreme-green.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the khaki icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of khaki icon.
	 */
	function __xotb_khaki_icon() {

		return plugins_url( 'images/icon-xtreme-khaki.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the orange icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of orange icon.
	 */
	function __xotb_orange_icon() {

		return plugins_url( 'images/icon-xtreme-orange.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the pink icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of pink icon.
	 */
	function __xotb_pink_icon() {

		return plugins_url( 'images/icon-xtreme-pink.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the red icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of red icon.
	 */
	function __xotb_red_icon() {

		return plugins_url( 'images/icon-xtreme-red.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the tan icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of tan icon.
	 */
	function __xotb_tan_icon() {

		return plugins_url( 'images/icon-xtreme-tan.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the turquoise icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of urquoise icon.
	 */
	function __xotb_turquoise_icon() {

		return plugins_url( 'images/icon-xtreme-turquoise.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning the yellow icon.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of yellow icon.
	 */
	function __xotb_yellow_icon() {

		return plugins_url( 'images/icon-xtreme-yellow.png', dirname( __FILE__ ) );
	}

	/**
	 * Helper function for returning a custom icon (icon-xotb.png) from stylesheet/child theme "images" folder.
	 *
	 * @since  1.1.0
	 *
	 * @return string Path/ string of xotb custom icon.
	 */
	function __xotb_child_images_icon() {

		return get_stylesheet_directory_uri() . '/images/icon-xotb.png';
	}


/**
 * Helper functions for returning icon class.
 *
 * @since  1.1.0
 *
 * @return NULL
 */
	/**
	 * Helper function for returning no icon class.
	 *
	 * @since  1.1.0
	 *
	 * @return NULL For no icon class.
	 */
	function __xotb_no_icon_display() {

		return NULL;
	}


/**
 * Misc. helper functions
 *
 * @since 1.1.0
 */
	/**
	 * Remove the "The Latest News From Xtreme Themes" dashboard widget
	 *
	 * Usage: add_action( 'init', '__xotb_remove_xtreme_dashboard_widget' );
	 *
	 * @since 1.1.0
	 */
	function __xotb_remove_xtreme_dashboard_widget() {

		remove_action( 'wp_dashboard_setup', 'xtreme_dashboard_rss_widget_setup' );
	}

	add_action( 'wp_before_admin_bar_render', 'ddw_xotb_remove_wpseo_yoast_toolbar', 5 );
	/**
	 * Disable original toolbar items of "WordPress SEO by Yoast"
	 *
	 * @since 1.1.0
	 */
	function ddw_xotb_remove_wpseo_yoast_toolbar() {

		if ( defined( 'XOTB_REMOVE_WPSEO_YOAST_TOOLBAR' ) && XOTB_REMOVE_WPSEO_YOAST_TOOLBAR ) {

			global $wp_admin_bar;

			$wp_admin_bar->remove_menu( 'wpseo-menu' );
		}

	}  // end function