<?php 
/**
 * Main plugin file.
 * This plugin adds useful admin links and resources for the Xtreme One
 *    Framework to the WordPress Toolbar / Admin Bar.
 *
 * @package     Xtreme One Toolbar
 * @author      David Decker
 * @copyright   Copyright (c) 2012-2014, David Decker - DECKERWEB
 * @license     GPL-2.0+
 * @link        http://twitter.com/deckerweb
 *
 * @wordpress-plugin
 * Plugin Name: Xtreme One Toolbar
 * Plugin URI:  http://genesisthemes.de/en/wp-plugins/xtreme-one-toolbar/
 * Description: This plugin adds useful admin links and resources for Xtreme One Framework to the WordPress Toolbar / Admin Bar.
 * Version:     1.2.0
 * Author:      David Decker - DECKERWEB
 * Author URI:  http://deckerweb.de/
 * License:     GPL-2.0+
 * License URI: http://www.opensource.org/licenses/gpl-license.php
 * Text Domain: xtreme-one-toolbar
 * Domain Path: /languages/
 *
 * Copyright (c) 2012-2014 David Decker - DECKERWEB
 *
 *     This file is part of Xtreme One Toolbar,
 *     a plugin for WordPress.
 *
 *     Xtreme One Toolbar is free software:
 *     You can redistribute it and/or modify it under the terms of the
 *     GNU General Public License as published by the Free Software
 *     Foundation, either version 2 of the License, or (at your option)
 *     any later version.
 *
 *     Xtreme One Toolbar is distributed in the hope that
 *     it will be useful, but WITHOUT ANY WARRANTY; without even the
 *     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *     PURPOSE. See the GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with WordPress. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.2.0
 */
if ( ! defined( 'WPINC' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Setting constants.
 *
 * @since 1.0.0
 */
/** Plugin directory */
define( 'XOTB_PLUGIN_DIR', trailingslashit( dirname( __FILE__ ) ) );

/** Plugin base directory */
define( 'XOTB_PLUGIN_BASEDIR', trailingslashit( dirname( plugin_basename( __FILE__ ) ) ) );


/**
 * Set filter for plugin's languages directory.
 *
 * @since  1.2.0
 *
 * @return string Path to plugin's languages directory.
 */
function ddw_xotb_plugin_lang_dir() {

	return apply_filters( 'xotb_filter_lang_dir', XOTB_PLUGIN_BASEDIR . 'languages' );

}  // end of function ddw_xotb_plugin_lang_dir


add_action( 'init', 'ddw_xotb_init' );
/**
 * Load the text domain for translation of the plugin.
 * Load admin helper functions - only within 'wp-admin'.
 * 
 * @since 1.0.0
 *
 * @uses  get_locale()
 * @uses  load_textdomain()
 * @uses  load_plugin_textdomain()
 * @uses  is_admin()
 */
function ddw_xotb_init() {

	/** Set unique textdomain string */
	$xotb_textdomain = 'xtreme-one-toolbar';

	/** The 'plugin_locale' filter is also used by default in load_plugin_textdomain() */
	$locale = apply_filters( 'plugin_locale', get_locale(), $xotb_textdomain );

	/** Set filter for WordPress languages directory */
	$xotb_wp_lang_dir = apply_filters(
		'xotb_filter_wp_lang_dir',
		trailingslashit( WP_LANG_DIR ) . 'xtreme-one-toolbar/' . $xotb_textdomain . '-' . $locale . '.mo'
	);

	/** Translations: First, look in WordPress' "languages" folder = custom & update-secure! */
	load_textdomain( $xotb_textdomain, $xotb_wp_lang_dir );

	/** Translations: Secondly, look in plugin's "languages" folder = default */
	load_plugin_textdomain( $xotb_textdomain, FALSE, esc_attr( ddw_xotb_plugin_lang_dir() ) );


	/** Include admin helper functions */
	if ( is_admin() ) {

		require_once( XOTB_PLUGIN_DIR . 'includes/xotb-admin.php' );

	}  // end if

	/** Define constants and set defaults for removing all or certain sections */
	if ( ! defined( 'XOTB_DISPLAY' ) ) {
		define( 'XOTB_DISPLAY', TRUE );
	}

	if ( ! defined( 'XOTB_RESOURCES_DISPLAY' ) ) {
		define( 'XOTB_RESOURCES_DISPLAY', TRUE );
	}

	if ( ! defined( 'XOTB_THEME_DISPLAY' ) ) {
		define( 'XOTB_THEME_DISPLAY', TRUE );
	}

	if ( ! defined( 'XOTB_EXTENSIONS_DISPLAY' ) ) {
		define( 'XOTB_EXTENSIONS_DISPLAY', TRUE );
	}

	if ( ! defined( 'XOTB_DE_DISPLAY' ) ) {
		define( 'XOTB_DE_DISPLAY', TRUE );
	}

	if ( ! defined( 'XOTB_TRANSLATIONS_DISPLAY' ) ) {
		define( 'XOTB_TRANSLATIONS_DISPLAY', TRUE );
	}

}  // end of function ddw_xotb_init


/**
 * Detect German locale based environment.
 *
 * @since  1.2.0
 *
 * @uses   get_locale() To detect current locale.
 *
 * @return bool TRUE if German based locale, otherwise FALSE.
 */
function ddw_xotb_is_german() {
	
	return ( in_array( get_locale(), array( 'de_DE', 'de_AT', 'de_CH', 'de_LU', 'gsw' ) ) ) ? TRUE : FALSE;

}  // end of function ddw_xotb_is_german


/**
 * Collect Xtreme One external resource links in an array.
 *
 * @since  1.2.0
 *
 * @uses   ddw_xotb_is_german() To detect German locale based environment.
 *
 * @return array Array of external link url strings.
 */
function ddw_xotb_resources_links() {

	/** Check for active WP locale version to define links */
	$xtob_resource_links = array(

		'url_home'      => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/product/xtreme/' ) : esc_url( 'http://marketpress.com/product/xtreme/' ),

		'url_themes'    => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/products/themes/' ) : esc_url( 'http://marketpress.com/products/themes/' ),

		'url_docs'      => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/dokumentation/xtreme/' ) : esc_url( 'http://marketpress.com/documentation/xtreme/' ),

		'url_hooks'     => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/dokumentation/xtreme/hook-referenz/' ) : esc_url( 'http://marketpress.com/documentation/xtreme/hook-references/' ),

		'url_css'       => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/dokumentation/xtreme/css/' ) : esc_url( 'http://marketpress.com/documentation/xtreme/css/' ),

		'url_cssyaml'   => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/dokumentation/xtreme/css/yaml-modifikationen/' ) : esc_url( 'http://marketpress.com/documentation/xtreme/css/yaml-modification/' ),

		'url_knowledge' => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/dokumentation/xtreme/knowledge-base-wissensdatenbank/' ) : esc_url( 'http://marketpress.com/documentation/xtreme/xtreme-knowledgebase/' ),

		'url_videos'    => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/dokumentation/xtreme/xtreme-theme-videos/' ) : esc_url( 'http://marketpress.com/documentation/xtreme/xtreme-theme-videos/' ),

		'url_support'   => ddw_xotb_is_german() ? esc_url( 'http://marketpress.de/support/forum/xtreme/' ) : esc_url( 'http://marketpress.com/support/forum/xtreme/' ),

	);  // end of array

	return $xtob_resource_links;

}  // end of function ddw_xotb_resources_links


add_action( 'admin_bar_menu', 'ddw_xotb_admin_bar_menu', 98 );
/**
 * Add new menu items to the WordPress Toolbar / Admin Bar.
 * 
 * @since  1.0.0
 *
 * @uses   ddw_xotb_resources_links()
 *
 * @global mixed $wp_admin_bar, $stylesheet
 */
function ddw_xotb_admin_bar_menu() {

	global $wp_admin_bar, $stylesheet;

	/**
	 * Allows for filtering the general user role/capability to see main & sub-level items
	 *
	 * Default role: 'manage_options'
	 */
	$xotb_filter_capability = apply_filters( 'xotb_filter_capability_all', 'manage_options' );

	/**
	 * Required WordPress cabability to display new admin bar entry
	 * Only showing items if toolbar / admin bar is activated and user is logged in!
	 */
	if ( ! is_user_logged_in()
		|| ! is_admin_bar_showing()
		|| ! current_user_can( esc_attr( $xotb_filter_capability ) )  // allows for custom filtering the required role/capability
		|| ( defined( 'XOTB_DISPLAY' ) && ! XOTB_DISPLAY )  // allows for custom disabling
	) {

		return;

	}  // end if


	/** First, check for WP 3.4+ function wp_get_theme() */
	if ( function_exists( 'wp_get_theme' ) ) {

		$xotb_stylesheet_name = wp_get_theme( $stylesheet );

	}
		/** Otherwise fall back to prior WP 3.4 default get_current_theme() */
	elseif ( function_exists( 'get_current_theme' ) ) {

		$xotb_stylesheet_name = get_current_theme();

	}  // end-if


	/** Set unique prefix */
	$prefix = 'ddw-xtreme-';
	
	/** Create parent menu item references */
	$xobar = $prefix . 'admin-bar';					// root level
		$xosupport = $prefix . 'xosupport';				// sub level: xo support
		$xocodex = $prefix . 'xocodex';					// sub level: xo codex
			$xocodexcss = $prefix . 'xocodexcss';				// third level: xo codex css
		$xosites = $prefix . 'xosites';					// sub level: xo sites
			$xoaffiliates = $prefix . 'xoaffiliates';			// third level: xo affiliates
		$xosettings = $prefix . 'xosettings';				// sub level: xo settings
		$xolayouts = $prefix . 'xolayouts';				// sub level: xo layouts
		$extgroup = $prefix . 'extgroup';				// sub level: extend group ("hook" place)
			$tgroup = $prefix . 'tgroup';				// sub level: theme group ("hook" place)
				$xochildsettings = $prefix . 'xochildsettings';		// third level theme: xtreme child themes
			$pgroup = $prefix . 'pgroup';				// sub level: plugins group ("hook" place)
				$extensions = $prefix . 'extensions';		// sub level: extensions
					$extwpseosm = $prefix . 'extwpseosm';		// third level plugin: wpseo
					$extyoastseo = $prefix . 'extyoastseo';		// third level plugin: wp seo yoast
					$extseoultimate = $prefix . 'extseoultimate';	// third level plugin: seo ultimate
					$extgdhs = $prefix . 'extgdhs';			// third level plugin: gdheadspace4
		$xogroup = $prefix . 'xogroup';				// sub level: xo group (resources)


	/** Make the "Xtreme (One)" name filterable within menu items */
	$xotb_xtreme_name = apply_filters(
		'xotb_filter_xtreme_name',
		__( 'Xtreme', 'xtreme-one-toolbar' )
	);

	/** Make the "Xtreme (One)" name's tooltip filterable within menu items */
	$xotb_xtreme_name_tooltip = apply_filters(
		'xotb_filter_xtreme_name_tooltip',
		_x( 'Xtreme One', 'Translators: For the tooltip', 'xtreme-one-toolbar' )
	);

//

	/** Display these items also when Xtreme One Framework is not installed */
	if ( defined( 'XOTB_RESOURCES_DISPLAY' ) && XOTB_RESOURCES_DISPLAY ) {

		/** Include plugin file with resources links */
		require_once( XOTB_PLUGIN_DIR . 'includes/xotb-resources.php' );

	}  // end-if


	/** Display language specific links only for these locales: de_DE, de_AT, de_CH, de_LU */
	if ( ( defined( 'XOTB_RESOURCES_DISPLAY' ) && XOTB_DE_DISPLAY )
		&& ( in_array( get_locale(), array( 'de_DE', 'de_AT', 'de_CH', 'de_LU', 'gsw' ) ) )
	) {

		/** German Xtreme One language packs */
		$xogroup_menu_items[ 'xo-languages-de' ] = array(
			'parent' => $xogroup,
			'title'  => __( 'German language files', 'xtreme-one-toolbar' ),
			'href'   => 'http://deckerweb.de/sprachdateien/xtreme-one-framework/',
			'meta'   => array( 'title' => __( 'German language files for Xtreme One Framework and more extensions', 'xtreme-one-toolbar' ) )
		);

	}  // end-if


	/** Show these items only if Xtreme One Framework is actually installed */
	if ( ( defined( 'XF_THEME_DIR' ) || get_template() == 'xtreme-one' )
		&& current_user_can( 'manage_options' )
	) {

		/** XO Settings section */
		$menu_items[ 'xosettings' ] = array(
			'parent' => $xobar,
			'title'  => __( 'Framework Settings', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'admin.php?page=xtreme_backend' ),
			'meta'   => array( 'target' => '', 'title' => _x( 'Framework Settings: Main Configuration', 'Translators: For the tooltip', 'xtreme-one-toolbar' ) )
		);

		/** XO Layouts section */
		$menu_items[ 'xolayouts' ] = array(
			'parent' => $xobar,
			'title'  => __( 'Layout Manager', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'admin.php?page=xtreme_layouts' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Layout Manager', 'xtreme-one-toolbar' ) )
		);
		$menu_items[ 'xol-add' ] = array(
			'parent' => $xolayouts,
			'title'  => __( 'Add new Layout', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'admin.php?page=xtreme_layouts&mode=add_layout' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Add new Layout', 'xtreme-one-toolbar' ) )
		);

		/** XO Widgets section */
		if ( current_user_can( 'edit_theme_options' ) ) {
			$menu_items[ 'xowidgets' ] = array(
				'parent' => $xobar,
				'title'  => esc_attr__( $xotb_xtreme_name ) . ' ' . __( 'Widgets', 'xtreme-one-toolbar' ),
				'href'   => admin_url( 'widgets.php' ),
				'meta'   => array( 'target' => '', 'title' => esc_attr__( $xotb_xtreme_name_tooltip ) . ' ' . __( 'Widgets', 'xtreme-one-toolbar' ) )
			);
		}  // end-if cap check

		$menu_items[ 'xowidgets-settings' ] = array(
			'parent' => $xobar,
			'title'  => esc_attr__( $xotb_xtreme_name ) . ' ' . __( 'Widget Config', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'admin.php?page=xtreme_widgets' ),
			'meta'   => array( 'target' => '', 'title' => esc_attr__( $xotb_xtreme_name_tooltip ) . ' ' . __( 'Widget Config', 'xtreme-one-toolbar' ) )
		);

		/** XO Backup/Export/Import section */
		$menu_items[ 'xobackup' ] = array(
			'parent' => $xobar,
			'title'  => __( 'Backup - Export/Import', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'admin.php?page=xtreme_backup' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Backup - Export/Import', 'xtreme-one-toolbar' ) )
		);

		/** XO Backup/Export/Import section */
		$menu_items[ 'xodocumentation' ] = array(
			'parent' => $xobar,
			'title'  => __( 'Inline Documentation', 'xtreme-one-toolbar' ),
			'href'   => admin_url( 'admin.php?page=inpsyde_documentation' ),
			'meta'   => array( 'target' => '', 'title' => __( 'Inline Documentation', 'xtreme-one-toolbar' ) )
		);

		/**
		 * Display last main item in the menu for active extensions/plugins
		 * ATTENTION: This is where plugins/extensions hook in on the sub-level hierarchy
		 *
		 * @since 1.0.0
		 */
		if ( ( defined( 'XOTB_EXTENSIONS_DISPLAY' ) && XOTB_EXTENSIONS_DISPLAY )
			&& current_user_can( 'activate_plugins' )
		) {

			$menu_items[ 'extensions' ] = array(
				'parent' => $pgroup,
				'title'  => __( 'Active Extensions', 'xtreme-one-toolbar' ),
				'href'   => is_network_admin() ? network_admin_url( 'plugins.php' ) : admin_url( 'plugins.php' ),
				'meta'   => array( 'target' => '', 'title' => __( 'Active Extensions', 'xtreme-one-toolbar' ) )
			);

		}  // end-if

	}

		/** If Xtreme One is not active: */
	else {

		/** If Xtreme One is not active, to avoid PHP notices */
		$menu_items = $xogroup_menu_items;

		/** If Xtreme One is not active and no icon filter is active, then display no icon */
		if ( ! has_filter( 'xotb_filter_main_icon' ) ) {
			add_filter( 'xotb_filter_main_item_icon_display', '__eddtb_no_icon_display' );
		}

	}  // end-if XO conditional


	/**
	 * Display links to active Xtreme One Child Themes settings' pages
	 */
		/** Include plugin file with theme support links */
		require_once( XOTB_PLUGIN_DIR . 'includes/xotb-themes.php' );


	/**
	 * Display links to active Xtreme One plugins/extensions settings' pages
	 */
		/** Include plugin file with plugin support links */
		require_once( XOTB_PLUGIN_DIR . 'includes/xotb-plugins.php' );


	/** Allow menu items to be filtered, but pass in parent menu item IDs */
	$menu_items = (array) apply_filters( 'ddw_xotb_menu_items',
		$menu_items, $xogroup_menu_items, $prefix, $xobar, 
						$xosupport, $xocodex, $xosites, $xosettings, $xolayouts, 
						$extgroup, $tgroup, $xochildsettings, $pgroup, $extensions, $extwpseosm, $extyoastseo, 
						$extseoultimate, $extgdhs, $xogroup
	);  // end of array


	/**
	 * Add the Xtreme One top-level menu item
	 */
		/** Filter the main item name */
		$xotb_main_item_title = apply_filters(
			'xotb_filter_main_item',
			__( 'Xtreme One', 'xtreme-one-toolbar' )
		);

		/** Filter the main item name's tooltip */
		$xotb_main_item_title_tooltip = apply_filters(
			'xotb_filter_main_item_tooltip',
			_x( 'Xtreme One Framework', 'Translators: For the tooltip', 'xtreme-one-toolbar' )
		);

		/** Filter the main item icon's class/display */
		$xotb_main_item_icon_display = apply_filters( 'xotb_filter_main_item_icon_display', 'icon-xtreme' );

		$wp_admin_bar->add_menu( array(
			'id'    => $xobar,
			'title' => esc_attr__( $xotb_main_item_title ),
			'href'  => admin_url( 'admin.php?page=xtreme_backend' ),
			'meta'  => array( 'class' => esc_attr( $xotb_main_item_icon_display ), 'title' => esc_attr__( $xotb_main_item_title_tooltip ) )
		) );


	/** Loop through the menu items */
	foreach ( $menu_items as $id => $menu_item ) {
		
		/** Add in the item ID */
		$menu_item[ 'id' ] = $prefix . $id;

		/** Add meta target to each item where it's not already set, so links open in new window/tab */
		if ( ! isset( $menu_item[ 'meta' ][ 'target' ] ) ) {

			$menu_item[ 'meta' ][ 'target' ] = '_blank';

		}

		/** Add class to links that open up in a new window/tab */
		if ( '_blank' === $menu_item[ 'meta' ][ 'target' ] ) {

			if ( ! isset( $menu_item['meta']['class'] ) ) {

				$menu_item['meta']['class'] = '';

			}  // end if

			$menu_item[ 'meta' ][ 'class' ] .= $prefix . 'xotb-new-tab';

		}  // end if

		/** Add menu items */
		$wp_admin_bar->add_menu( $menu_item );

	}  // end foreach


	/**
	 * Action Hook 'xotb_custom_main_items'
	 * allows for hooking other main items in
	 */
	do_action( 'xotb_custom_main_items' );


	/** Extend Group: Main Entry */
	$wp_admin_bar->add_group( array(
		'parent' => $xobar,
		'id'     => $extgroup,
	) );

		/** Theme Group: Main Entry */
		if ( defined( 'XOTB_THEME_DISPLAY' ) && XOTB_THEME_DISPLAY ) {

			$wp_admin_bar->add_group( array(
				'parent' => $extgroup,
				'id'     => $tgroup,
			) );

		}  // end-if

		/** Plugin Group: Main Entry */
		$wp_admin_bar->add_group( array(
			'parent' => $extgroup,
			'id'     => $pgroup,
		) );


	/** XO Group: Main Entry */
	$wp_admin_bar->add_group( array(
		'parent' => $xobar,
		'id'     => $xogroup,
		'meta'   => array( 'class' => 'ab-sub-secondary' )
	) );

	/** XO Group: Loop through the group menu items */
	foreach ( $xogroup_menu_items as $id => $xogroup_menu_item ) {
		
		/** XO Group: Add in the item ID */
		$xogroup_menu_item[ 'id' ] = $prefix . $id;

		/** XO Group: Add meta target to each item where it's not already set, so links open in new window/tab */
		if ( ! isset( $xogroup_menu_item[ 'meta' ][ 'target' ] ) ) {

			$xogroup_menu_item[ 'meta' ][ 'target' ] = '_blank';

		}  // end if

		/** XO Group: Add class to links that open up in a new window/tab */
		if ( '_blank' === $xogroup_menu_item[ 'meta' ][ 'target' ] ) {

			if ( ! isset( $xogroup_menu_item[ 'meta' ][ 'class' ] ) ) {

				$xogroup_menu_item[ 'meta' ][ 'class' ] = '';

			}  // end if

			$xogroup_menu_item[ 'meta' ][ 'class' ] .= $prefix . 'xotb-new-tab';

		}  // end if

		/** XO Group: Add menu items */
		$wp_admin_bar->add_menu( $xogroup_menu_item );

	}  // end foreach


	/**
	 * Action Hook 'xotb_custom_group_items'
	 * allows for hooking other XO Group items in
	 */
	do_action( 'xotb_custom_group_items' );

}  // end of main function ddw_xotb_admin_bar_menu


add_action( 'wp_head', 'ddw_xotb_admin_style' );
add_action( 'admin_head', 'ddw_xotb_admin_style' );
/**
 * Add the styles for new WordPress Toolbar / Admin Bar entry
 * 
 * @since 1.0.0
 */
function ddw_xotb_admin_style() {

	/** No styles if admin bar is disabled or user is not logged in or items are disabled via constant */
	if ( ! is_admin_bar_showing() || ! is_user_logged_in() || ! XOTB_DISPLAY ) {

		return;

	}  // end if

	/** Add CSS styles to wp_head/admin_head */
	$xotb_main_icon = apply_filters(
		'xotb_filter_main_icon',
		plugins_url( 'xtreme-one-toolbar/images/icon-xtreme.png', dirname( __FILE__ ) )
	);

	?>
	<style type="text/css">
		#wpadminbar.nojs .ab-top-menu > li.menupop.icon-xtreme:hover > .ab-item,
		#wpadminbar .ab-top-menu > li.menupop.icon-xtreme.hover > .ab-item,
		#wpadminbar.nojs .ab-top-menu > li.menupop.icon-xtreme > .ab-item,
		#wpadminbar .ab-top-menu > li.menupop.icon-xtreme > .ab-item {
      		background-image: url(<?php echo esc_url_raw( $xotb_main_icon ); ?>);
			background-repeat: no-repeat;
			background-position: 0.85em 50%;
			padding-left: 30px;
		}
		#wp-admin-bar-ddw-xtreme-xo-languages-de > .ab-item:before {
			content: '• ';
		}
		#wp-admin-bar-ddw-xtreme-extwpseosm > .ab-item {
			min-width: 60px !important;
		}
	</style>
	<?php

}  // end of function ddw_xotb_admin_style


/**
 * Helper functions for custom branding of the plugin
 *
 * @since 1.1.0
 */
	/** Include plugin file with special custom stuff */
	require_once( XOTB_PLUGIN_DIR . 'includes/xotb-branding.php' );


/**
 * Returns current plugin's header data in a flexible way.
 *
 * @since  1.2.0
 *
 * @uses   is_admin()
 * @uses   get_plugins()
 * @uses   plugin_basename()
 *
 * @param  $xotb_plugin_value
 *
 * @return string Plugin data.
 */
function ddw_xotb_plugin_get_data( $xotb_plugin_value ) {

	/** Bail early if we are not in wp-admin */
	if ( ! is_admin() ) {
		return;
	}

	/** Include WordPress plugin data */
	if ( ! function_exists( 'get_plugins' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	}

	$xotb_plugin_folder = get_plugins( '/' . plugin_basename( dirname( __FILE__ ) ) );
	$xotb_plugin_file = basename( ( __FILE__ ) );

	return $xotb_plugin_folder[ $xotb_plugin_file ][ $xotb_plugin_value ];

}  // end of function ddw_xotb_plugin_get_data